@@ -80,55 +80,49 @@ class Client(object):
 
     def callback_request(self, pdu):
         """Si le SMSC dit qu'il a envoyé le SMS, on compte comme OK tests"""
-        if (
-            (self.msisdn[-9:]).startswith("34")
-            or (self.msisdn[-9:]).startswith("39")
-        ):
-            pass
-        else:
-            infos = {
-                'date': datetime.now().strftime('%d-%m-%Y %H:%M:%S'),
-                'msisdn': self.msisdn,
-                'submit': True
-                }
-            msg_id = pdu.message_id.decode("utf-8")
-            message_id = int(str(msg_id), 16)
-            kwargs = {
-                'engine': self.db_engine,
-                'user': self.db_user,
-                'password': self.db_password,
-                'host': self.db_host,
-                'port': self.db_port,
-                'name': self.db_name
-                }
-            url = self.database_url(**kwargs)
-            with records.Database(url) as db:
-                sql = (
-                    "INSERT INTO get_delivery_sms "
-                    "(request_id, message_id, status , "
-                    "code, msisdn, msisdn_source, submit_date) "
-                    "VALUES "
-                    "(:request_id, :message_id, :status, "
-                    ":code, :msisdn, :msisdn_source, :submit_date)"
-                    )
-                LOGS.logger.info(sql)
-                db.query(
-                    sql,
-                    request_id=self.request_id,
-                    message_id=str(message_id),
-                    status='PENDING',
-                    code='111',
-                    msisdn=self.msisdn[-9:],
-                    msisdn_source=self.source[-9:],
-                    submit_date=datetime.now().strftime('%y%m%d%H%M')
-                    )
-            msg = '<<< seq={} msg_id={} msisdn={}'.format(
-                pdu.sequence,
-                str(message_id),
-                self.msisdn
+        infos = {
+            'date': datetime.now().strftime('%d-%m-%Y %H:%M:%S'),
+            'msisdn': self.msisdn,
+            'submit': True
+            }
+        msg_id = pdu.message_id.decode("utf-8")
+        message_id = int(str(msg_id), 16)
+        kwargs = {
+            'engine': self.db_engine,
+            'user': self.db_user,
+            'password': self.db_password,
+            'host': self.db_host,
+            'port': self.db_port,
+            'name': self.db_name
+            }
+        url = self.database_url(**kwargs)
+        with records.Database(url) as db:
+            sql = (
+                "INSERT INTO get_delivery_sms "
+                "(request_id, message_id, status , "
+                "code, msisdn, msisdn_source, submit_date) "
+                "VALUES "
+                "(:request_id, :message_id, :status, "
+                ":code, :msisdn, :msisdn_source, :submit_date)"
                 )
-            journal.send(msg, REQUEST_ID=self.request_id)
-            QUEUE.put(infos)
+            LOGS.logger.info(sql)
+            db.query(
+                sql,
+                request_id=self.request_id,
+                message_id=str(message_id),
+                status='PENDING',
+                code='111',
+                msisdn=self.msisdn[-9:],
+                msisdn_source=self.source[-9:],
+                submit_date=datetime.now().strftime('%y%m%d%H%M')
+                )
+        msg = '<<< seq={} msg_id={} msisdn={}'.format(
+            pdu.sequence,
+            str(message_id),
+            self.msisdn
+            )
+        journal.send(msg, REQUEST_ID=self.request_id)
+        QUEUE.put(infos)
 
     def callback_response(self, pdu):
         """Si le SMSC a envoyé le sms on enregistre """
@@ -169,28 +163,15 @@ class Client(object):
                     "AND code=:err_code AND message_id=:message_id"
                     )
                 LOGS.logger.info(sql)
-                if (msisdn_dest[-9:]).startswith("34") or (msisdn_dest[-9:]).startswith("39"):
-                    LOGS.logger.info("-----", msisdn_dest, "-----")
-                    db.query(
-                        sql,
-                        message_id=infos['id'][1:],
-                        done_date=infos['done_date'].strip(),
-                        status="DELIVRD",
-                        code=infos['err'],
-                        err_code='111',
-                        msisdn=msisdn_dest[-9:]
-                        )
-                else:
-                    LOGS.logger.info("-----{}: {}".format(msisdn_dest, infos['stat']))
-                    db.query(
-                        sql,
-                        message_id=infos['id'][1:],
-                        done_date=infos['done_date'].strip(),
-                        status=infos['stat'],
-                        code=infos['err'],
-                        err_code='111',
-                        msisdn=msisdn_dest[-9:]
-                        )
+                db.query(
+                    sql,
+                    message_id=infos['id'][1:],
+                    done_date=infos['done_date'].strip(),
+                    status=infos['stat'],
+                    code=infos['err'],
+                    err_code='111',
+                    msisdn=msisdn_dest[-9:]
+                    )
             msg = '<<< msg_id={} status={} msisdn={} code={}'.format(
                 infos['id'][1:],
                 infos['stat'],
